/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "CoapServer.h"
#include <coap2/coap.h>
#include <map>
#include <functional>

namespace org {
namespace apache {
namespace nifi {
namespace minifi {
namespace coap {


std::map<coap_resource_t*, std::function<CoapResponse(CoapQuery)>> CoapServer::functions_;
CoapServer::~CoapServer() {
  running_ = false;
  future.get();
  if (server_) {
    free_server(server_);
  }
}


} /* namespace coap */
} /* namespace minifi */
} /* namespace nifi */
} /* namespace apache */
} /* namespace org */
